# Generated by Django 5.2.8 on 2025-11-22 05:57

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='Name')),
                ('name_ascii', models.CharField(max_length=100, verbose_name='ASCII Name')),
                ('geoname_id', models.IntegerField(unique=True, verbose_name='Geoname ID')),
                ('continent', models.CharField(max_length=50, verbose_name='Continent')),
                ('code2', models.CharField(max_length=2, unique=True, verbose_name='ISO Alpha-2 Code')),
                ('code3', models.CharField(max_length=3, unique=True, verbose_name='ISO Alpha-3 Code')),
                ('calling_code', models.CharField(max_length=10, verbose_name='Calling Code')),
                ('postal_code_format', models.CharField(blank=True, max_length=100, null=True, verbose_name='Postal Code Format')),
                ('postal_code_regex', models.CharField(blank=True, max_length=255, null=True, verbose_name='Postal Code Regex')),
                ('flag', models.ImageField(blank=True, null=True, upload_to='flags/', verbose_name='Flag')),
            ],
            options={
                'verbose_name': 'Country',
                'verbose_name_plural': 'Countries',
            },
        ),
        migrations.CreateModel(
            name='Region',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='Name')),
                ('name_ascii', models.CharField(max_length=100, verbose_name='ASCII Name')),
                ('geoname_id', models.IntegerField(unique=True, verbose_name='Geoname ID')),
                ('code', models.CharField(max_length=10, verbose_name='Code')),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='regions', to='geobank.country', verbose_name='Country')),
            ],
            options={
                'verbose_name': 'Region',
                'verbose_name_plural': 'Regions',
                'unique_together': {('country', 'code')},
            },
        ),
        migrations.CreateModel(
            name='City',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='Name')),
                ('name_ascii', models.CharField(max_length=100, verbose_name='ASCII Name')),
                ('geoname_id', models.IntegerField(unique=True, verbose_name='Geoname ID')),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='cities', to='geobank.country', verbose_name='Country')),
                ('region', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='cities', to='geobank.region', verbose_name='Region')),
            ],
            options={
                'verbose_name': 'City',
                'verbose_name_plural': 'Cities',
            },
        ),
    ]



from django.db import models
from django.utils.translation import gettext_lazy as _


class Country(models.Model):
    name = models.CharField(
        max_length=100,
        verbose_name=_("Name"),
    )
    name_ascii = models.CharField(
        max_length=100,
        verbose_name=_("ASCII Name"),
    )
    geoname_id = models.IntegerField(
        unique=True,
        verbose_name=_("Geoname ID"),
    )
    continent = models.CharField(
        max_length=50,
        verbose_name=_("Continent"),
    )
    code2 = models.CharField(
        max_length=2,
        unique=True,
        verbose_name=_("ISO Alpha-2 Code"),
    )
    code3 = models.CharField(
        max_length=3,
        unique=True,
        verbose_name=_("ISO Alpha-3 Code"),
    )
    calling_code = models.CharField(
        max_length=10,
        verbose_name=_("Calling Code"),
    )
    postal_code_format = models.CharField(
        max_length=100,
        null=True,
        blank=True,
        verbose_name=_("Postal Code Format"),
    )
    postal_code_regex = models.CharField(
        max_length=255,
        null=True,
        blank=True,
        verbose_name=_("Postal Code Regex"),
    )
    flag_png = models.URLField(
        max_length=500, blank=True, null=True, verbose_name=_("Flag PNG URL")
    )
    flag_svg = models.URLField(
        max_length=500, blank=True, null=True, verbose_name=_("Flag PNG URL")
    )
    is_active = models.BooleanField(
        default=True, verbose_name=_("Is Active")
    )

    class Meta:
        verbose_name = _("Country")
        verbose_name_plural = _("Countries")


class Region(models.Model):
    name = models.CharField(
        max_length=100,
        verbose_name=_("Name"),
    )
    name_ascii = models.CharField(
        max_length=100,
        verbose_name=_("ASCII Name"),
    )
    geoname_id = models.IntegerField(
        unique=True,
        verbose_name=_("Geoname ID"),
    )
    code = models.CharField(
        max_length=10,
        verbose_name=_("Code"),
    )
    country = models.ForeignKey(
        Country,
        on_delete=models.CASCADE,
        related_name='regions',
        verbose_name=_("Country"),
    )
    is_active = models.BooleanField(
        default=True, verbose_name=_("Is Active")
    )

    class Meta:
        verbose_name = _("Region")
        verbose_name_plural = _("Regions")
        unique_together = ("country", "code", )


class City(models.Model):
    name = models.CharField(
        max_length=100,
        verbose_name=_("Name"),
    )
    name_ascii = models.CharField(
        max_length=100,
        verbose_name=_("ASCII Name"),
    )
    geoname_id = models.IntegerField(
        unique=True,
        verbose_name=_("Geoname ID"),
    )
    country = models.ForeignKey(
        Country,
        on_delete=models.CASCADE,
        related_name='cities',
        verbose_name=_("Country"),
    )
    region = models.ForeignKey(
        Region,
        on_delete=models.CASCADE,
        related_name='cities',
        verbose_name=_("Region"),
        null=True,
        blank=True,
    )
    is_active = models.BooleanField(
        default=True, verbose_name=_("Is Active")
    )

    class Meta:
        verbose_name = _("City")
        verbose_name_plural = _("Cities")



# Generated by Django 5.2.8 on 2025-11-22 07:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geobank', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='country',
            name='flag',
        ),
        migrations.AddField(
            model_name='country',
            name='flag_png',
            field=models.URLField(blank=True, max_length=500, null=True, verbose_name='Flag PNG URL'),
        ),
        migrations.AddField(
            model_name='country',
            name='flag_svg',
            field=models.URLField(blank=True, max_length=500, null=True, verbose_name='Flag PNG URL'),
        ),
    ]



# Generated by Django 5.2.8 on 2025-11-22 12:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geobank', '0002_remove_country_flag_country_flag_png_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='city',
            name='is_active',
            field=models.BooleanField(default=True, verbose_name='Is Active'),
        ),
        migrations.AddField(
            model_name='country',
            name='is_active',
            field=models.BooleanField(default=True, verbose_name='Is Active'),
        ),
        migrations.AddField(
            model_name='region',
            name='is_active',
            field=models.BooleanField(default=True, verbose_name='Is Active'),
        ),
    ]
